#include "draggablewidget.h"
#include "ui_draggablewidget.h"

#include <QDebug>
#include <QMouseEvent>

#include <QBitmap>

DraggableWidget::DraggableWidget( QWidget* parent ) :
    QWidget( parent, Qt::Window | Qt::FramelessWindowHint ),
    ui( new Ui::DraggableWidget ), dx( 0 ), dy( 0 ) {
    ui->setupUi( this );

    ui->lbTitle->setText( windowTitle() );

    connect( ui->btnQuit, SIGNAL( clicked( bool ) ), qApp, SLOT( quit() ) );

    setWindowOpacity( 0.8 );

    QPixmap maskPix( ":/images/mask.png" );
    setMask( maskPix.scaled( size() ).mask() );
}

DraggableWidget::~DraggableWidget() {
    delete ui;
}

void DraggableWidget::mouseMoveEvent( QMouseEvent* e ) {
    if( e->buttons() | Qt::LeftButton ) {
        setGeometry(
            pos().x() + ( e->x() - dx ),
            pos().y() + ( e->y() - dy ),
            width(),
            height()
        );
    }
}

void DraggableWidget::mousePressEvent( QMouseEvent* e ) {
    if( e->button() == Qt::LeftButton ) {
        dx = e->x();
        dy = e->y();
        setCursor( Qt::OpenHandCursor );
    }
}

void DraggableWidget::mouseReleaseEvent( QMouseEvent* e ) {
    if( e->button() == Qt::LeftButton ) {
        setCursor( Qt::ArrowCursor );
    }
}
